@@ -31,9 +31,8 @@ describe 'nova' do
         is_expected.to contain_nova_config('glance/api_servers').with_value('http://localhost:9292')
       end
 
-      it 'configures auth_strategy' do
-        is_expected.to contain_nova_config('api/auth_strategy').with_value('keystone')
-        is_expected.to_not contain_nova_config('DEFAULT/use_deprecated_auth').with_value(false)
+      it 'does not configure auth_strategy' do
+        is_expected.not_to contain_nova_config('api/auth_strategy')
       end
 
       it 'configures rabbit' do
@@ -49,7 +48,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
-        is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
@@ -62,7 +61,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -111,8 +109,6 @@ describe 'nova' do
           :ssl_only                                => true,
           :cert                                    => '/etc/ssl/private/snakeoil.pem',
           :key                                     => '/etc/ssl/certs/snakeoil.pem',
-          :dhcp_domain                             => 'foo',
-
         }
       end
 
@@ -133,7 +129,6 @@ describe 'nova' do
 
       it 'configures auth_strategy' do
         is_expected.to contain_nova_config('api/auth_strategy').with_value('foo')
-        is_expected.to_not contain_nova_config('DEFAULT/use_deprecated_auth').with_value(true)
       end
 
       it 'configures rabbit' do
@@ -174,13 +169,12 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
+        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
         is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('MyAZ')
-        is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
-        is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('foo')
       end
 
       context 'with multiple notification_driver' do
