@@ -1,13 +1,11 @@
 require 'spec_helper'
 
 describe 'nova::scheduler' do
-
   let :pre_condition do
     'include nova'
   end
 
-  shared_examples 'nova-scheduler' do
-
+  shared_examples 'nova::scheduler' do
     it { is_expected.to contain_package('nova-scheduler').with(
       :name   => platform_params[:scheduler_package_name],
       :ensure => 'present'
@@ -22,6 +20,11 @@ describe 'nova::scheduler' do
     it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
     it { is_expected.to contain_nova_config('scheduler/driver').with_value('filter_scheduler') }
     it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/max_placement_results').with_value('<SERVICE DEFAULT>') }
+
+    it { is_expected.to contain_class('nova::availability_zone') }
 
     context 'with manage_service as false' do
       let :params do
@@ -66,6 +69,30 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value(15) }
     end
 
+    context 'with query_placement_for_image_type_support' do
+      let :params do
+        { :query_placement_for_image_type_support => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value(true) }
+    end
+
+    context 'with limit_tenants_to_placement_aggregate' do
+      let :params do
+        { :limit_tenants_to_placement_aggregate => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value(true) }
+    end
+
+    context 'with max_placement_results' do
+      let :params do
+        { :max_placement_results => 10 }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/max_placement_results').with_value(10) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
         "include nova"
@@ -73,7 +100,7 @@ describe 'nova::scheduler' do
 
       it { is_expected.to_not contain_nova_config('database/connection') }
       it { is_expected.to_not contain_nova_config('database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with overridden database parameters' do
@@ -87,38 +114,34 @@ describe 'nova::scheduler' do
       end
 
       it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection       => 'mysql://user:pass@db/db',
-        :slave_connection => 'mysql://user:pass@slave/db',
-        :idle_timeout     => '30',
+        :connection              => 'mysql://user:pass@db/db',
+        :slave_connection        => 'mysql://user:pass@slave/db',
+        :connection_recycle_time => '30',
       )}
     end
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian', :os_workers => 4 })
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({ :os_workers => 4 }))
+      end
 
-    let :platform_params do
-      { :scheduler_package_name => 'nova-scheduler',
-        :scheduler_service_name => 'nova-scheduler' }
-    end
+      let (:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :scheduler_package_name => 'nova-scheduler',
+            :scheduler_service_name => 'nova-scheduler' }
+        when 'RedHat'
+          { :scheduler_package_name => 'openstack-nova-scheduler',
+            :scheduler_service_name => 'openstack-nova-scheduler' }
+        end
+      end
 
-    it_configures 'nova-scheduler'
+      it_behaves_like 'nova::scheduler'
+    end
   end
-
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat', :os_workers => 4 })
-    end
-
-    let :platform_params do
-      { :scheduler_package_name => 'openstack-nova-scheduler',
-        :scheduler_service_name => 'openstack-nova-scheduler' }
-    end
-
-    it_configures 'nova-scheduler'
-  end
-
 end
